@@ -49,6 +49,7 @@ SSO_Browser_Preference=""
 Sleep_Time_To_Wait_And_Get_Authocode=""
 Timer_Delay_to_Launch=""
 Server_AGENT=""
+Os_Independent=""
 # Class to run the windows commands. will have a run_command method
 class runWindowsCommand:
     
@@ -330,6 +331,7 @@ def processInputParams():
     global Sleep_Time_To_Wait_And_Get_Authocode
     global Timer_Delay_to_Launch
     global Server_AGENT
+    global Os_Independent
     printNicely("Please enter the details when asked, leave empty if value not needed.")
     while versionNumber =="":
         versionNumber=raw_input("Enter Patch/Tag number :")
@@ -404,16 +406,27 @@ def processInputParams():
     printNicely("Note:time interval to launch blusync agent if not running.(applicable only from 2.5.3.1 agent onwards)..", True)
     Ans =raw_input("(Please enter the time interval in min):")
     Timer_Delay_to_Launch=Ans
-    while Server_AGENT =="":
-        printNicely("Note:Server_AGENT field is applicable only from 2.5.3.4 agent onwards..", True)
-        Ans =raw_input("(press y to create server agent else n to create normal agent):")
+    while Os_Independent =="":
+        printNicely("os independent field is applicable only from 2.5.3.4.3.17 agent onwards..", True)
+        Ans =raw_input("(press y for os independent agent else n):")
         if (check_user_input(Ans) == 1):
-            Server_AGENT="serveragent"
+            Os_Independent="true"
+            Server_AGENT="OSIndependent"
         elif (check_user_input(Ans) == 2):
-            Server_AGENT="nonserveragent"
+            Os_Independent="false"
         else:
             printNicely("please enter the correct value", True)
-    printNicely("You sure all details entered are correct?", True)
+    if Os_Independent =="false":
+        while Server_AGENT =="":
+            printNicely("Note:Server_AGENT field is applicable only from 2.5.3.4 agent onwards..", True)
+            Ans =raw_input("(press y to create server agent else n to create normal agent):")
+            if (check_user_input(Ans) == 1):
+                Server_AGENT="serveragent"
+            elif (check_user_input(Ans) == 2):
+                Server_AGENT="nonserveragent"
+            else:
+                printNicely("please enter the correct value", True)
+  
 			
     printNicely("You sure all details entered are correct?", True)
     while InputKey =="":
@@ -433,6 +446,7 @@ def processInputParams():
             Sleep_Time_To_Wait_And_Get_Authocode=""
             Timer_Delay_to_Launch=""
             Server_AGENT=""
+            Os_Independent=""
             processInputParams()
         elif (check_user_input(Ans) == 1):
             InputKey="yes"
@@ -458,6 +472,7 @@ def saveUserInputsInConfig():
         config.set("config", "Sleep_Time_To_Wait_And_Get_Authocode", Sleep_Time_To_Wait_And_Get_Authocode)
         config.set("config", "Timer_Delay_to_Launch", Timer_Delay_to_Launch)
         config.set("config", "Server_AGENT", Server_AGENT)
+        config.set("config", "Os_Independent", Os_Independent)
         config.write(open("ConfigFile.properties", "w"))
     except Exception as e:
         printNicely("Error in creating  config file..", True)
